@@ -1,11 +1,11 @@
+#include <cmath>
 #include <iostream>
-#include <Rmath.h>
-#include <R.h>
 #include <Rinternals.h>
 #include <R_ext/Utils.h>
 #include <cstdlib>
 #include <ctime> 
 #include "tree.h"
+#include <R_ext/Rdynload.h>
 
 using namespace std;
 
@@ -13,10 +13,10 @@ class Container{
 	 public:
          int nInstances;
          int nVariables;
-	 variable **variables;
+	     variable **variables;
          double **data;
          int *weights;
-         int* elitismList;
+         int *elitismList;
          int nTrees;
          int minBucket;
          int minSplit;
